@@ -7,9 +7,10 @@ import re
 import string
 import sys
 from collections import defaultdict
+from functools import lru_cache
 from itertools import chain, groupby
+from pathlib import Path
 
-import six
 import tomlkit
 from attr import validators
 from packaging.markers import InvalidMarker, Marker, Op, Value, Variable
@@ -20,7 +21,6 @@ from tomlkit.container import Container
 from tomlkit.items import AoT, Array, Bool, InlineTable, Item, String, Table
 from urllib3 import util as urllib3_util
 from urllib3.util import parse_url as urllib3_parse
-from vistir.compat import lru_cache
 from vistir.misc import dedup
 from vistir.path import is_valid_url
 
@@ -28,33 +28,31 @@ from ..environment import MYPY_RUNNING
 from ..utils import SCHEME_LIST, VCS_LIST, is_star
 
 if MYPY_RUNNING:
+    from typing import Iterable  # noqa
+    from typing import (
+        Any,
+        AnyStr,
+        Dict,
+        List,
+        Match,
+        Optional,
+        Sequence,
+        Set,
+        Text,
+        Tuple,
+        TypeVar,
+        Union,
+    )
+
     from attr import _ValidatorType  # noqa
+    from packaging.markers import Marker as PkgResourcesMarker
+    from packaging.markers import Op as PkgResourcesOp
+    from packaging.markers import Value as PkgResourcesValue
+    from packaging.markers import Variable as PkgResourcesVariable
     from packaging.requirements import Requirement as PackagingRequirement
     from pip_shims.shims import Link
     from pkg_resources import Requirement as PkgResourcesRequirement
-    from packaging.markers import (
-        Op as PkgResourcesOp,
-        Variable as PkgResourcesVariable,
-        Value as PkgResourcesValue,
-        Marker as PkgResourcesMarker,
-    )
-    from typing import (
-        Union,
-        Optional,
-        List,
-        Set,
-        Any,
-        TypeVar,
-        Tuple,
-        Sequence,
-        Dict,
-        Text,
-        AnyStr,
-        Match,
-        Iterable,  # noqa
-    )
     from urllib3.util.url import Url
-    from vistir.compat import Path
 
     _T = TypeVar("_T")
     TMarker = Union[Marker, PkgResourcesMarker]
@@ -115,9 +113,9 @@ def optional_instance_of(cls):
 def create_link(link):
     # type: (AnyStr) -> Link
 
-    if not isinstance(link, six.string_types):
+    if not isinstance(link, str):
         raise TypeError("must provide a string to instantiate a new link")
-    from pip_shims.shims import Link
+    from pip_shims.shims import Link  # noqa: F811
 
     return Link(link)
 
@@ -178,14 +176,13 @@ def tomlkit_dict_to_python(toml_dict):
 
 def get_url_name(url):
     # type: (AnyStr) -> AnyStr
-    """
-    Given a url, derive an appropriate name to use in a pipfile.
+    """Given a url, derive an appropriate name to use in a pipfile.
 
     :param str url: A url to derive a string from
     :returns: The name of the corresponding pipfile entry
     :rtype: Text
     """
-    if not isinstance(url, six.string_types):
+    if not isinstance(url, str):
         raise TypeError("Expected a string, got {0!r}".format(url))
     return urllib3_util.parse_url(url).host
 
@@ -193,7 +190,7 @@ def get_url_name(url):
 def init_requirement(name):
     # type: (AnyStr) -> TRequirement
 
-    if not isinstance(name, six.string_types):
+    if not isinstance(name, str):
         raise TypeError("must supply a name to generate a requirement")
     from pkg_resources import Requirement
 
@@ -207,13 +204,13 @@ def init_requirement(name):
 
 def extras_to_string(extras):
     # type: (Iterable[S]) -> S
-    """Turn a list of extras into a string
+    """Turn a list of extras into a string.
 
     :param List[str]] extras: a list of extras to format
     :return: A string of extras
     :rtype: str
     """
-    if isinstance(extras, six.string_types):
+    if isinstance(extras, str):
         if extras.startswith("["):
             return extras
         else:
@@ -225,7 +222,7 @@ def extras_to_string(extras):
 
 def parse_extras(extras_str):
     # type: (AnyStr) -> List[AnyStr]
-    """Turn a string of extras into a parsed extras list
+    """Turn a string of extras into a parsed extras list.
 
     :param str extras_str: An extras string
     :return: A sorted list of extras
@@ -240,7 +237,7 @@ def parse_extras(extras_str):
 
 def specs_to_string(specs):
     # type: (List[Union[STRING_TYPE, Specifier]]) -> AnyStr
-    """Turn a list of specifier tuples into a string
+    """Turn a list of specifier tuples into a string.
 
     :param List[Union[Specifier, str]] specs: a list of specifiers to format
     :return: A string of specifiers
@@ -248,7 +245,7 @@ def specs_to_string(specs):
     """
 
     if specs:
-        if isinstance(specs, six.string_types):
+        if isinstance(specs, str):
             return specs
         try:
             extras = ",".join(["".join(spec) for spec in specs])
@@ -288,8 +285,7 @@ def build_vcs_uri(
 
 def _get_parsed_url(url):
     # type: (S) -> Url
-    """
-    This is a stand-in function for `urllib3.util.parse_url`
+    """This is a stand-in function for `urllib3.util.parse_url`
 
     The orignal function doesn't handle special characters very well, this simply splits
     out the authentication section, creates the parsed url, then puts the authentication
@@ -311,7 +307,7 @@ def _get_parsed_url(url):
 
 def convert_direct_url_to_url(direct_url):
     # type: (AnyStr) -> AnyStr
-    """Converts direct URLs to standard, link-style URLs
+    """Converts direct URLs to standard, link-style URLs.
 
     Given a direct url as defined by *PEP 508*, convert to a :class:`~pip_shims.shims.Link`
     compatible URL by moving the name and extras into an **egg_fragment**.
@@ -352,8 +348,7 @@ def convert_direct_url_to_url(direct_url):
 
 def convert_url_to_direct_url(url, name=None):
     # type: (AnyStr, Optional[AnyStr]) -> AnyStr
-    """
-    Converts normal link-style URLs to direct urls.
+    """Converts normal link-style URLs to direct urls.
 
     Given a :class:`~pip_shims.shims.Link` compatible URL, convert to a direct url as
     defined by *PEP 508* by extracting the name and extras from the **egg_fragment**.
@@ -366,7 +361,7 @@ def convert_url_to_direct_url(url, name=None):
     :raises ValueError: Raised when the URL can't be parsed or a name can't be found.
     :raises TypeError: When a non-string input is provided.
     """
-    if not isinstance(url, six.string_types):
+    if not isinstance(url, str):
         raise TypeError(
             "Expected a string to convert to a direct url, got {0!r}".format(url)
         )
@@ -410,15 +405,14 @@ def get_version(pipfile_entry):
             return ""
         return pipfile_entry.get("version", "").strip().lstrip("(").rstrip(")")
 
-    if isinstance(pipfile_entry, six.string_types):
+    if isinstance(pipfile_entry, str):
         return pipfile_entry.strip().lstrip("(").rstrip(")")
     return ""
 
 
 def strip_extras_markers_from_requirement(req):
     # type: (TRequirement) -> TRequirement
-    """
-    Strips extras markers from requirement instances.
+    """Strips extras markers from requirement instances.
 
     Given a :class:`~packaging.requirements.Requirement` instance with markers defining
     *extra == 'name'*, strip out the extras from the markers and return the cleaned
@@ -485,9 +479,8 @@ def get_default_pyproject_backend():
 
 def get_pyproject(path):
     # type: (Union[STRING_TYPE, Path]) -> Optional[Tuple[List[STRING_TYPE], STRING_TYPE]]
-    """
-    Given a base path, look for the corresponding ``pyproject.toml`` file and return its
-    build_requires and build_backend.
+    """Given a base path, look for the corresponding ``pyproject.toml`` file
+    and return its build_requires and build_backend.
 
     :param AnyStr path: The root path of the project, should be a directory (will be truncated)
     :return: A 2 tuple of build requirements and the build backend
@@ -495,7 +488,6 @@ def get_pyproject(path):
     """
     if not path:
         return
-    from vistir.compat import Path
 
     if not isinstance(path, Path):
         path = Path(path)
@@ -510,7 +502,7 @@ def get_pyproject(path):
         backend = get_default_pyproject_backend()
     else:
         pyproject_data = {}
-        with io.open(pp_toml.as_posix(), encoding="utf-8") as fh:
+        with open(pp_toml.as_posix(), encoding="utf-8") as fh:
             pyproject_data = tomlkit.loads(fh.read())
         build_system = pyproject_data.get("build-system", None)
         if build_system is None:
@@ -530,7 +522,7 @@ def get_pyproject(path):
 
 def split_markers_from_line(line):
     # type: (AnyStr) -> Tuple[AnyStr, Optional[AnyStr]]
-    """Split markers from a dependency"""
+    """Split markers from a dependency."""
     quote_chars = ["'", '"']
     line_quote = next(
         iter(quote for quote in quote_chars if line.startswith(quote)), None
@@ -562,15 +554,14 @@ def split_vcs_method_from_uri(uri):
 
 def split_ref_from_uri(uri):
     # type: (AnyStr) -> Tuple[AnyStr, Optional[AnyStr]]
-    """
-    Given a path or URI, check for a ref and split it from the path if it is present,
-    returning a tuple of the original input and the ref or None.
+    """Given a path or URI, check for a ref and split it from the path if it is
+    present, returning a tuple of the original input and the ref or None.
 
     :param AnyStr uri: The path or URI to split
     :returns: A 2-tuple of the path or URI and the ref
     :rtype: Tuple[AnyStr, Optional[AnyStr]]
     """
-    if not isinstance(uri, six.string_types):
+    if not isinstance(uri, str):
         raise TypeError("Expected a string, received {0!r}".format(uri))
     parsed = _get_parsed_url(uri)
     path = parsed.path if parsed.path else ""
@@ -738,8 +729,7 @@ def get_pinned_version(ireq):
 
 
 def is_pinned_requirement(ireq):
-    """
-    Returns whether an InstallRequirement is a "pinned" requirement.
+    """Returns whether an InstallRequirement is a "pinned" requirement.
 
     An InstallRequirement is considered pinned if:
 
@@ -763,9 +753,8 @@ def is_pinned_requirement(ireq):
 
 
 def as_tuple(ireq):
-    """
-    Pulls out the (name: str, version:str, extras:(str)) tuple from the pinned InstallRequirement.
-    """
+    """Pulls out the (name: str, version:str, extras:(str)) tuple from the
+    pinned InstallRequirement."""
 
     if not is_pinned_requirement(ireq):
         raise TypeError("Expected a pinned InstallRequirement, got {}".format(ireq))
@@ -777,24 +766,19 @@ def as_tuple(ireq):
 
 
 def full_groupby(iterable, key=None):
-    """
-    Like groupby(), but sorts the input on the group key first.
-    """
+    """Like groupby(), but sorts the input on the group key first."""
 
     return groupby(sorted(iterable, key=key), key=key)
 
 
 def flat_map(fn, collection):
-    """
-    Map a function over a collection and flatten the result by one-level
-    """
+    """Map a function over a collection and flatten the result by one-level."""
 
     return chain.from_iterable(map(fn, collection))
 
 
 def lookup_table(values, key=None, keyval=None, unique=False, use_lists=False):
-    """
-    Builds a dict-based lookup table (index) elegantly.
+    """Builds a dict-based lookup table (index) elegantly.
 
     Supports building normal and unique lookup tables.  For example:
 
@@ -855,7 +839,7 @@ def lookup_table(values, key=None, keyval=None, unique=False, use_lists=False):
 
 
 def name_from_req(req):
-    """Get the name of the requirement"""
+    """Get the name of the requirement."""
     if hasattr(req, "project_name"):
         # from pkg_resources, such as installed dists for pip-sync
         return req.project_name
@@ -867,8 +851,7 @@ def name_from_req(req):
 def make_install_requirement(
     name, version=None, extras=None, markers=None, constraint=False
 ):
-    """
-    Generates an :class:`~pip._internal.req.req_install.InstallRequirement`.
+    """Generates an :class:`~pip._internal.req.req_install.InstallRequirement`.
 
     Create an InstallRequirement from the supplied metadata.
 
@@ -903,7 +886,8 @@ def make_install_requirement(
 
 
 def version_from_ireq(ireq):
-    """version_from_ireq Extract the version from a supplied :class:`~pip._internal.req.req_install.InstallRequirement`
+    """version_from_ireq Extract the version from a supplied
+    :class:`~pip._internal.req.req_install.InstallRequirement`
 
     :param ireq: An InstallRequirement
     :type ireq: :class:`~pip._internal.req.req_install.InstallRequirement`
@@ -924,7 +908,8 @@ def _get_requires_python(candidate):
 
 
 def clean_requires_python(candidates):
-    """Get a cleaned list of all the candidates with valid specifiers in the `requires_python` attributes."""
+    """Get a cleaned list of all the candidates with valid specifiers in the
+    `requires_python` attributes."""
     all_candidates = []
     sys_version = ".".join(map(str, sys.version_info[:3]))
     from packaging.version import parse as parse_version
@@ -985,25 +970,24 @@ def normalize_name(pkg):
     :rtype: AnyStr
     """
 
-    assert isinstance(pkg, six.string_types)
+    assert isinstance(pkg, str)
     return pkg.replace("_", "-").lower()
 
 
 def get_name_variants(pkg):
     # type: (STRING_TYPE) -> Set[STRING_TYPE]
-    """
-    Given a packager name, get the variants of its name for both the canonicalized
-    and "safe" forms.
+    """Given a packager name, get the variants of its name for both the
+    canonicalized and "safe" forms.
 
     :param AnyStr pkg: The package to lookup
     :returns: A list of names.
     :rtype: Set
     """
 
-    if not isinstance(pkg, six.string_types):
+    if not isinstance(pkg, str):
         raise TypeError("must provide a string to derive package names")
-    from pkg_resources import safe_name
     from packaging.utils import canonicalize_name
+    from pkg_resources import safe_name
 
     pkg = pkg.lower()
     names = {safe_name(pkg), canonicalize_name(pkg), pkg.replace("-", "_")}
@@ -1012,29 +996,26 @@ def get_name_variants(pkg):
 
 def read_source(path, encoding="utf-8"):
     # type: (S, S) -> S
-    """
-    Read a source file and get the contents with proper encoding for Python 2/3.
+    """Read a source file and get the contents with proper encoding for Python
+    2/3.
 
     :param AnyStr path: the file path
     :param AnyStr encoding: the encoding that defaults to UTF-8
     :returns: The contents of the source file
     :rtype: AnyStr
     """
-    if six.PY3:
-        with open(path, "r", encoding=encoding) as fp:
-            return fp.read()
-    else:
-        with open(path, "r") as fp:
-            return fp.read()
+    with open(path, "r", encoding=encoding) as fp:
+        return fp.read()
 
 
 def expand_env_variables(line):
     # type: (AnyStr) -> AnyStr
     """Expand the env vars in a line following pip's standard.
-    https://pip.pypa.io/en/stable/reference/pip_install/#id10
+    https://pip.pypa.io/en/stable/reference/pip_install/#id10.
 
-    Matches environment variable-style values in '${MY_VARIABLE_1}' with the
-    variable name consisting of only uppercase letters, digits or the '_'
+    Matches environment variable-style values in '${MY_VARIABLE_1}' with
+    the variable name consisting of only uppercase letters, digits or
+    the '_'
     """
 
     def replace_with_env(match):
